@@ -7,23 +7,29 @@
 #   Template Toolkit modules.
 #
 # AUTHOR
-#   Andy Wardley   <abw@wardley.org>
+#   Andy Wardley   <abw@kfs.org>
 #
 # COPYRIGHT
-#   Copyright (C) 1996-2007 Andy Wardley.  All Rights Reserved.
+#   Copyright (C) 1996-2000 Andy Wardley.  All Rights Reserved.
+#   Copyright (C) 1998-2000 Canon Research Centre Europe Ltd.
 #
 #   This module is free software; you can redistribute it and/or
 #   modify it under the same terms as Perl itself.
 #
+#------------------------------------------------------------------------
+#
+#   $Id: Base.pm,v 2.7 2001/03/30 08:09:20 abw Exp $
+#
 #========================================================================
  
 package Template::Base;
 
-use strict;
-use warnings;
-use Template::Constants;
+require 5.004;
 
-our $VERSION = 2.78;
+use strict;
+use vars qw( $VERSION );
+
+$VERSION = sprintf("%d.%02d", q$Revision: 2.7 $ =~ /(\d+)\.(\d+)/);
 
 
 #------------------------------------------------------------------------
@@ -39,29 +45,29 @@ our $VERSION = 2.78;
 sub new {
     my $class = shift;
     my ($argnames, @args, $arg, $cfg);
-#    $class->error('');         # always clear package $ERROR var?
+#    $class->error('');		# always clear package $ERROR var?
 
-    {   no strict 'refs';
-        no warnings 'once';
-        $argnames = \@{"$class\::BASEARGS"} || [ ];
+    {	no strict qw( refs );
+	$argnames = \@{"$class\::BASEARGS"} || [ ];
     }
 
     # shift off all mandatory args, returning error if undefined or null
     foreach $arg (@$argnames) {
-        return $class->error("no $arg specified")
-            unless ($cfg = shift);
-        push(@args, $cfg);
+	return $class->error("no $arg specified")
+	    unless ($cfg = shift);
+	push(@args, $cfg);
     }
 
     # fold all remaining args into a hash, or use provided hash ref
-    $cfg  = defined $_[0] && UNIVERSAL::isa($_[0], 'HASH') ? shift : { @_ };
+#    local $" = ', ';
+#    print STDERR "args: [@_]\n";
+    $cfg  = UNIVERSAL::isa($_[0], 'HASH') ? shift : { @_ };
 
     my $self = bless {
-        (map { ($_ => shift @args) } @$argnames),
-        _ERROR  => '',
-        DEBUG   => 0,
+	map { ($_ => shift @args) } @$argnames,
+	_ERROR  => ''
     }, $class;
-    
+
     return $self->_init($cfg) ? $self : $class->error($self->error);
 }
 
@@ -82,15 +88,15 @@ sub error {
     my $errvar;
 
     { 
-        no strict qw( refs );
-        $errvar = ref $self ? \$self->{ _ERROR } : \${"$self\::ERROR"};
+	no strict qw( refs );
+	$errvar = ref $self ? \$self->{ _ERROR } : \${"$self\::ERROR"};
     }
     if (@_) {
-        $$errvar = ref($_[0]) ? shift : join('', @_);
-        return undef;
+	$$errvar = ref($_[0]) ? shift : join('', @_);
+	return undef;
     }
     else {
-        return $$errvar;
+	return $$errvar;
     }
 }
 
@@ -115,59 +121,37 @@ sub DEBUG {
     print STDERR "DEBUG: ", @_;
 }
 
-sub debug {
-    my $self = shift;
-    my $msg  = join('', @_);
-    my ($pkg, $file, $line) = caller();
-
-    unless ($msg =~ /\n$/) {
-        $msg .= ($self->{ DEBUG } & Template::Constants::DEBUG_CALLER)
-            ? " at $file line $line\n"
-            : "\n";
-    }
-
-    print STDERR "[$pkg] $msg";
-}
-
-
-#------------------------------------------------------------------------
-# module_version()
-#
-# Returns the current version number.
-#------------------------------------------------------------------------
-
-sub module_version {
-    my $self = shift;
-    my $class = ref $self || $self;
-    no strict 'refs';
-    return ${"${class}::VERSION"};
-}
-
-
 1;
 
 __END__
 
+
+#------------------------------------------------------------------------
+# IMPORTANT NOTE
+#   This documentation is generated automatically from source
+#   templates.  Any changes you make here may be lost.
+# 
+#   The 'docsrc' documentation source bundle is available for download
+#   from http://www.template-toolkit.org/docs.html and contains all
+#   the source templates, XML files, scripts, etc., from which the
+#   documentation for the Template Toolkit is built.
+#------------------------------------------------------------------------
+
 =head1 NAME
 
 Template::Base - Base class module implementing common functionality
 
 =head1 SYNOPSIS
 
-    package My::Module;
+    package Template::MyModule;
     use base qw( Template::Base );
-    
+
     sub _init {
-        my ($self, $config) = @_;
-        $self->{ doodah } = $config->{ doodah }
-            || return $self->error("No 'doodah' specified");
-        return $self;
+	my ($self, $config) = @_;
+	$self->{ doodah } = $config->{ doodah }
+	    || return $self->error("No 'doodah' specified");
+	return $self;
     }
-    
-    package main;
-    
-    my $object = My::Module->new({ doodah => 'foobar' })
-        || die My::Module->error();
 
 =head1 DESCRIPTION
 
@@ -180,104 +164,66 @@ functionality for various Template Toolkit modules.
 
 Constructor method which accepts a reference to a hash array or a list 
 of C<name =E<gt> value> parameters which are folded into a hash.  The 
-C<_init()> method is then called, passing the configuration hash and should
+_init() method is then called, passing the configuration hash and should
 return true/false to indicate success or failure.  A new object reference
 is returned, or undef on error.  Any error message raised can be examined
-via the L<error()> class method or directly via the C<$ERROR> package variable 
+via the error() class method or directly via the package variable ERROR
 in the derived class.
 
-    my $module = My::Module->new({ ... })
-        || die My::Module->error(), "\n";
+    my $module = Template::MyModule->new({ ... })
+        || die Template::MyModule->error(), "\n";
 
-    my $module = My::Module->new({ ... })
-        || die "constructor error: $My::Module::ERROR\n";
+    my $module = Template::MyModule->new({ ... })
+        || die "constructor error: $Template::MyModule::ERROR\n";
 
-=head2 error($msg, ...)
+=head2 error($msg)
 
-May be called as an object method to get/set the internal C<_ERROR> member
-or as a class method to get/set the C<$ERROR> variable in the derived class's
+May be called as an object method to get/set the internal _ERROR member
+or as a class method to get/set the $ERROR variable in the derived class's
 package.
 
-    my $module = My::Module->new({ ... })
-        || die My::Module->error(), "\n";
+    my $module = Template::MyModule->new({ ... })
+        || die Template::MyModule->error(), "\n";
 
     $module->do_something() 
-        || die $module->error(), "\n";
+	|| die $module->error(), "\n";
 
 When called with parameters (multiple params are concatenated), this
 method will set the relevant variable and return undef.  This is most
 often used within object methods to report errors to the caller.
 
-    package My::Module;
-    
+    package Template::MyModule;
+
+    ...
+
     sub foobar {
-        my $self = shift;
-        
-        # some other code...
-        
-        return $self->error('some kind of error...')
-            if $some_condition;
+	my $self = shift;
+	...
+	return $self->error('some kind of error...')
+	    if $some_condition;
+	...
     }
 
-=head2 debug($msg, ...)
-
-Generates a debugging message by concatenating all arguments
-passed into a string and printing it to C<STDERR>.  A prefix is
-added to indicate the module of the caller.
-
-    package My::Module;
-    
-    sub foobar {
-        my $self = shift;
-        
-        $self->debug('called foobar()');
-        
-        # some other code...
-    }
-
-When the C<foobar()> method is called, the following message
-is sent to C<STDERR>:
-
-    [My::Module] called foobar()
-
-Objects can set an internal C<DEBUG> value which the C<debug()>
-method will examine.  If this value sets the relevant bits
-to indicate C<DEBUG_CALLER> then the file and line number of
-the caller will be appened to the message.
-
-    use Template::Constants qw( :debug );
-    
-    my $module = My::Module->new({
-        DEBUG => DEBUG_SERVICE | DEBUG_CONTEXT | DEBUG_CALLER,
-    });
-    
-    $module->foobar();
-
-This generates an error message such as:
-
-    [My::Module] called foobar() at My/Module.pm line 6
-
 =head1 AUTHOR
 
-Andy Wardley E<lt>abw@wardley.orgE<gt> L<http://wardley.org/>
+Andy Wardley E<lt>abw@kfs.orgE<gt>
+
+L<http://www.andywardley.com/|http://www.andywardley.com/>
+
+=head1 VERSION
+
+Template Toolkit version 2.01, released on 30th March 2001.
 
 =head1 COPYRIGHT
 
-Copyright (C) 1996-2007 Andy Wardley.  All Rights Reserved.
+  Copyright (C) 1996-2001 Andy Wardley.  All Rights Reserved.
+  Copyright (C) 1998-2001 Canon Research Centre Europe Ltd.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
 =head1 SEE ALSO
 
-L<Template>
+L<Template|Template>
 
-=cut
 
-# Local Variables:
-# mode: perl
-# perl-indent-level: 4
-# indent-tabs-mode: nil
-# End:
-#
-# vim: expandtab shiftwidth=4:
