@@ -25,7 +25,7 @@
 #
 #----------------------------------------------------------------------------
 #
-# $Id: Directive.pm,v 2.7 2000/12/01 15:29:35 abw Exp $
+# $Id: Directive.pm,v 2.9 2001/03/27 11:58:52 abw Exp $
 #
 #============================================================================
 
@@ -38,7 +38,7 @@ use vars qw( $VERSION $DEBUG $PRETTY $WHILE_MAX );
 use Template::Constants;
 use Template::Exception;
 
-$VERSION = sprintf("%d.%02d", q$Revision: 2.7 $ =~ /(\d+)\.(\d+)/);
+$VERSION = sprintf("%d.%02d", q$Revision: 2.9 $ =~ /(\d+)\.(\d+)/);
 
 $WHILE_MAX = 1000 unless defined $WHILE_MAX;
 $PRETTY    = 0 unless defined $PRETTY;
@@ -70,7 +70,7 @@ sub template {
 
     return <<EOF;
 sub {
-    my \$context = shift || die "template sub called without context\n";
+    my \$context = shift || die "template sub called without context\\n";
     my \$stash   = \$context->stash;
     my \$output  = '';
     my \$error;
@@ -161,6 +161,9 @@ sub quoted {
     return '' unless @$items;
     return $items->[0] if scalar @$items == 1;
     return '(' . join(' . ', @$items) . ')';
+#    my $r = '(' . join(' . ', @$items) . ' . "")';
+#    print STDERR "[$r]\n";
+#    return $r;
 }
 
 
@@ -231,6 +234,21 @@ sub args {
     return '[ ' . join(', ', @$args) . ' ]';
 }
 
+#------------------------------------------------------------------------
+# filenames(\@names)
+#------------------------------------------------------------------------
+
+sub filenames {
+    my ($class, $names) = @_;
+    if (@$names > 1) {
+	$names = '[ ' . join(', ', @$names) . ' ]';
+    }
+    else {
+	$names = shift @$names;
+    }
+    return $names;
+}
+
 
 #------------------------------------------------------------------------
 # get($expr)                                                    [% foo %]
@@ -284,26 +302,28 @@ sub default {
 
 
 #------------------------------------------------------------------------
-# insert($file)                                         [% INSERT file %] 
+# insert(\@nameargs)                                    [% INSERT file %] 
+#         # => [ [ $file, ... ], \@args ]
 #------------------------------------------------------------------------
 
 sub insert {
     my ($class, $nameargs) = @_;
     my ($file, $args) = @$nameargs;
+    $file = $class->filenames($file);
     return "$OUTPUT \$context->insert($file);"; 
 }
 
 
-
 #------------------------------------------------------------------------
 # include(\@nameargs)                    [% INCLUDE template foo = bar %] 
-#          # => [ $file, \@args ]    
+#          # => [ [ $file, ... ], \@args ]    
 #------------------------------------------------------------------------
 
 sub include {
     my ($class, $nameargs) = @_;
     my ($file, $args) = @$nameargs;
     my $hash = shift @$args;
+    $file = $class->filenames($file);
     $file .= @$hash ? ', { ' . join(', ', @$hash) . ' }' : '';
     return "$OUTPUT \$context->include($file);"; 
 }
@@ -311,13 +331,14 @@ sub include {
 
 #------------------------------------------------------------------------
 # process(\@nameargs)                    [% PROCESS template foo = bar %] 
-#         # => [ $file, \@args ]
+#         # => [ [ $file, ... ], \@args ]
 #------------------------------------------------------------------------
 
 sub process {
     my ($class, $nameargs) = @_;
     my ($file, $args) = @$nameargs;
     my $hash = shift @$args;
+    $file = $class->filenames($file);
     $file .= @$hash ? ', { ' . join(', ', @$hash) . ' }' : '';
     return "$OUTPUT \$context->process($file);"; 
 }
@@ -426,7 +447,7 @@ EOF
 
 #------------------------------------------------------------------------
 # wrapper(\@nameargs, $block)            [% WRAPPER template foo = bar %] 
-#          # => [ $file, \@args ]    
+#          # => [ [$file,...], \@args ]    
 #------------------------------------------------------------------------
 
 sub wrapper {
@@ -434,12 +455,17 @@ sub wrapper {
     my ($file, $args) = @$nameargs;
     my $hash = shift @$args;
 
+    local $" = ', ';
+#    print STDERR "wrapper([@$file], { @$hash })\n";
+
+    return $class->multi_wrapper($file, $hash, $block)
+	if @$file > 1;
+    $file = shift @$file;
+
     $block = pad($block, 1) if $PRETTY;
-#    push(@$hash, "'content'", '$content');
     push(@$hash, "'content'", '$output');
     $file .= @$hash ? ', { ' . join(', ', @$hash) . ' }' : '';
 
-
     return <<EOF;
 
 # WRAPPER
@@ -452,6 +478,31 @@ EOF
 }
 
 
+sub multi_wrapper {
+    my ($class, $file, $hash, $block) = @_;
+    $block = pad($block, 1) if $PRETTY;
+
+    push(@$hash, "'content'", '$output');
+    $hash = @$hash ? ', { ' . join(', ', @$hash) . ' }' : '';
+
+    $file = join(', ', reverse @$file);
+#    print STDERR "multi wrapper: $file\n";
+
+    return <<EOF;
+
+# WRAPPER
+$OUTPUT do {
+    my \$output = '';
+$block
+    foreach ($file) {
+	\$output = \$context->include(\$_$hash); 
+    }
+    \$output;
+};
+EOF
+}
+
+
 #------------------------------------------------------------------------
 # while($expr, $block)                                 [% WHILE x < 10 %]
 #                                                         ...
@@ -597,7 +648,7 @@ EOF
 
 #------------------------------------------------------------------------
 # throw(\@nameargs)                           [% THROW foo "bar error" %]
-#       # => [ $type, \@args ]
+#       # => [ [$type], \@args ]
 #------------------------------------------------------------------------
 
 sub throw {
@@ -605,6 +656,9 @@ sub throw {
     my ($type, $args) = @$nameargs;
     my $hash = shift(@$args);
     my $info = shift(@$args);
+    $type = shift @$type;	    # uses same parser production as INCLUDE
+				    # etc., which allow multiple names
+				    # e.g. INCLUDE foo+bar+baz
 
     if (! $info) {
 	$args = "$type, undef";
@@ -667,21 +721,61 @@ sub stop {
 
 #------------------------------------------------------------------------
 # use(\@lnameargs)                         [% USE alias = plugin(args) %]
-#     # => [ $file, \@args, $alias ]
+#     # => [ [$file, ...], \@args, $alias ]
 #------------------------------------------------------------------------
 
 sub use {
     my ($class, $lnameargs) = @_;
     my ($file, $args, $alias) = @$lnameargs;
+    $file = shift @$file;	# same production rule as INCLUDE
     $alias ||= $file;
     $args = &args($class, $args);
     $file .= ", $args" if $args;
-    my $set = &assign($class, $alias, '$plugin'); 
+#    my $set = &assign($class, $alias, '$plugin'); 
     return "# USE\n"
 	 . "\$stash->set($alias,\n"
          . "            \$context->plugin($file));";
 }
 
+#------------------------------------------------------------------------
+# view(\@nameargs, $block)                           [% VIEW name args %]
+#     # => [ [$file, ... ], \@args ]
+#------------------------------------------------------------------------
+
+sub view {
+    my ($class, $nameargs, $block, $defblocks) = @_;
+    my ($name, $args) = @$nameargs;
+    my $hash = shift @$args;
+    $name = shift @$name;	# same production rule as INCLUDE
+    $block = pad($block, 1) if $PRETTY;
+
+    if (%$defblocks) {
+	$defblocks = join(",\n", map { "'$_' => $defblocks->{ $_ }" }
+				keys %$defblocks);
+	$defblocks = pad($defblocks, 1) if $PRETTY;
+	$defblocks = "{\n$defblocks\n}";
+	push(@$hash, "'blocks'", $defblocks);
+    }
+    $hash = @$hash ? '{ ' . join(', ', @$hash) . ' }' : '';
+
+    return <<EOF;
+# VIEW
+do {
+    my \$output = '';
+    my \$oldv = \$stash->get('view');
+    my \$view = \$context->view($hash);
+    \$stash->set($name, \$view);
+    \$stash->set('view', \$view);
+
+$block
+
+    \$stash->set('view', \$oldv);
+    \$view->seal();
+    \$output;
+};
+EOF
+}
+
 
 #------------------------------------------------------------------------
 # perl($block)
@@ -702,8 +796,8 @@ $OUTPUT do {
 
 $block
 
-    \$Template::Perl::context = \$context;
-    \$Template::Perl::stash   = \$stash;
+    local(\$Template::Perl::context) = \$context;
+    local(\$Template::Perl::stash)   = \$stash;
 
     my \$result = '';
     tie *Template::Perl::PERLOUT, 'Template::TieString', \\\$result;
@@ -760,6 +854,7 @@ EOF
 sub filter {
     my ($class, $lnameargs, $block) = @_;
     my ($name, $args, $alias) = @$lnameargs;
+    $name = shift @$name;
     $args = &args($class, $args);
     $args = $args ? "$args, $alias" : ", undef, $alias"
 	if $alias;
@@ -838,7 +933,7 @@ sub macro {
     \$params = { } unless ref(\$params) eq 'HASH';
     \$params = { \%args, %\$params };
 
-    \$stash = \$context->localise(\$params);
+    my \$stash = \$context->localise(\$params);
     eval {
 $block
     };
@@ -857,7 +952,7 @@ EOF
     my \$params = \$_[0] if ref(\$_[0]) eq 'HASH';
     my \$output = '';
 
-    \$stash = \$context->localise(\$params);
+    my \$stash = \$context->localise(\$params);
     eval {
 $block
     };
