@@ -8,29 +8,55 @@
 #   directive for iterating through data sets.  This may be
 #   sub-classed to define more specific iterator types.
 #
+#   An iterator is an object which provides a consistent way to
+#   navigate through data which may have a complex underlying form.
+#   This implementation uses the get_first() and get_next() methods to
+#   iterate through a dataset.  The get_first() method is called once
+#   to perform any data initialisation and return the first value,
+#   then get_next() is called repeatedly to return successive values.
+#   Both these methods return a pair of values which are the data item
+#   itself and a status code.  The default implementation handles
+#   iteration through an array (list) of elements which is passed by
+#   reference to the constructor.  An empty list is used if none is
+#   passed.  The module may be sub-classed to provide custom
+#   implementations which iterate through any kind of data in any
+#   manner as long as it can conforms to the get_first()/get_next()
+#   interface.  The object also implements the get_all() method for
+#   returning all remaining elements as a list reference.
+#
+#   For further information on iterators see "Design Patterns", by the 
+#   "Gang of Four" (Erich Gamma, Richard Helm, Ralph Johnson, John 
+#   Vlissides), Addision-Wesley, ISBN 0-201-63361-2.
+#
 # AUTHOR
-#   Andy Wardley   <abw@wardley.org>
+#   Andy Wardley   <abw@kfs.org>
 #
 # COPYRIGHT
-#   Copyright (C) 1996-2007 Andy Wardley.  All Rights Reserved.
+#   Copyright (C) 1996-2000 Andy Wardley.  All Rights Reserved.
+#   Copyright (C) 1998-2000 Canon Research Centre Europe Ltd.
 #
 #   This module is free software; you can redistribute it and/or
 #   modify it under the same terms as Perl itself.
 #
+#----------------------------------------------------------------------------
+#
+# $Id: Iterator.pm,v 2.5 2001/03/30 08:09:23 abw Exp $
+#
 #============================================================================
 
 package Template::Iterator;
 
+require 5.004;
+
 use strict;
-use warnings;
-use base 'Template::Base';
+use vars qw( $VERSION $DEBUG $AUTOLOAD );    # AUTO?
+use base qw( Template::Base );
 use Template::Constants;
 use Template::Exception;
-use Scalar::Util qw(blessed);
 
-our $VERSION = 2.68;
-our $DEBUG   = 0 unless defined $DEBUG;
-our $AUTOLOAD;
+$VERSION = sprintf("%d.%02d", q$Revision: 2.5 $ =~ /(\d+)\.(\d+)/);
+$DEBUG   = 0 unless defined $DEBUG;
+
 
 #========================================================================
 #                      -----  CLASS METHODS -----
@@ -50,22 +76,22 @@ sub new {
     my $params = shift || { };
 
     if (ref $data eq 'HASH') {
-        # map a hash into a list of { key => ???, value => ??? } hashes,
-        # one for each key, sorted by keys
-        $data = [ map { { key => $_, value => $data->{ $_ } } }
-                  sort keys %$data ];
+	# map a hash into a list of { key => ???, value => ??? } hashes,
+	# one for each key, sorted by keys
+	$data = [ map { { key => $_, value => $data->{ $_ } } }
+		  sort keys %$data ];
     }
-    elsif (blessed($data) && $data->can('as_list')) {
-        $data = $data->as_list();
+    elsif (UNIVERSAL::can($data, 'as_list')) {
+	$data = $data->as_list();
     }
     elsif (ref $data ne 'ARRAY') {
-        # coerce any non-list data into an array reference
-        $data  = [ $data ] ;
+	# coerce any non-list data into an array reference
+	$data  = [ $data ] ;
     }
 
     bless {
-        _DATA  => $data,
-        _ERROR => '',
+	_DATA  => $data,
+	_ERROR => '',
     }, $class;
 }
 
@@ -95,7 +121,7 @@ sub get_first {
 
     # initialise various counters, flags, etc.
     @$self{ qw( SIZE MAX INDEX COUNT FIRST LAST ) } 
-            = ( $size, $size - 1, $index, 1, 1, $size > 1 ? 0 : 1, undef );
+	    = ( $size, $size - 1, $index, 1, 1, $size > 1 ? 0 : 1, undef );
     @$self{ qw( PREV NEXT ) } = ( undef, $self->{ _DATASET }->[ $index + 1 ]);
 
     return $self->{ _DATASET }->[ $index ];
@@ -118,22 +144,22 @@ sub get_next {
 
     # warn about incorrect usage
     unless (defined $index) {
-        my ($pack, $file, $line) = caller();
-        warn("iterator get_next() called before get_first() at $file line $line\n");
-        return (undef, Template::Constants::STATUS_DONE);   ## RETURN ##
+	my ($pack, $file, $line) = caller();
+	warn("iterator get_next() called before get_first() at $file line $line\n");
+	return (undef, Template::Constants::STATUS_DONE);   ## RETURN ##
     }
 
     # if there's still some data to go...
     if ($index < $max) {
-        # update counters and flags
-        $index++;
-        @$self{ qw( INDEX COUNT FIRST LAST ) }
-        = ( $index, $index + 1, 0, $index == $max ? 1 : 0 );
-        @$self{ qw( PREV NEXT ) } = @$data[ $index - 1, $index + 1 ];
-        return $data->[ $index ];                           ## RETURN ##
+	# update counters and flags
+	$index++;
+	@$self{ qw( INDEX COUNT FIRST LAST ) }
+	        = ( $index, $index + 1, 0, $index == $max ? 1 : 0 );
+	@$self{ qw( PREV NEXT ) } = @$data[ $index - 1, $index + 1 ];
+	return $data->[ $index ];			    ## RETURN ##
     }
     else {
-        return (undef, Template::Constants::STATUS_DONE);   ## RETURN ##
+	return (undef, Template::Constants::STATUS_DONE);   ## RETURN ##
     }
 }
 
@@ -153,39 +179,19 @@ sub get_all {
     my ($max, $index) = @$self{ qw( MAX INDEX ) };
     my @data;
 
-    # handle cases where get_first() has yet to be called.
-    unless (defined $index) {
-        my ($first, $status) = $self->get_first;
-
-        # refresh $max and $index, after get_first updates MAX and INDEX
-        ($max, $index) = @$self{ qw( MAX INDEX ) };
-
-        # empty lists are handled here.
-        if ($status && $status == Template::Constants::STATUS_DONE) {
-            return (undef, Template::Constants::STATUS_DONE);   ## RETURN ##
-        }
-
-        push @data, $first;
-
-        ## if there's nothing left in the iterator, return the single value.
-        unless ($index < $max) {
-            return \@data;
-        }
-    }
-
     # if there's still some data to go...
     if ($index < $max) {
-        $index++;
-        push @data, @{ $self->{ _DATASET } } [ $index..$max ];
-        
-        # update counters and flags
-        @$self{ qw( INDEX COUNT FIRST LAST ) }
-        = ( $max, $max + 1, 0, 1 );
+	$index++;
+	@data = @{ $self->{ _DATASET } } [ $index..$max ];
 
-        return \@data;                                      ## RETURN ##
+	# update counters and flags
+	@$self{ qw( INDEX COUNT FIRST LAST ) }
+	        = ( $max, $max + 1, 0, 1 );
+
+	return \@data;					    ## RETURN ##
     }
     else {
-        return (undef, Template::Constants::STATUS_DONE);   ## RETURN ##
+	return (undef, Template::Constants::STATUS_DONE);   ## RETURN ##
     }
 }
     
@@ -223,14 +229,14 @@ sub AUTOLOAD {
 sub _dump {
     my $self = shift;
     join('',
-         "  Data: ", $self->{ _DATA  }, "\n",
-         " Index: ", $self->{ INDEX  }, "\n",
-         "Number: ", $self->{ NUMBER }, "\n",
-         "   Max: ", $self->{ MAX    }, "\n",
-         "  Size: ", $self->{ SIZE   }, "\n",
-         " First: ", $self->{ FIRST  }, "\n",
-         "  Last: ", $self->{ LAST   }, "\n",
-         "\n"
+	 "  Data: ", $self->{ _DATA  }, "\n",
+	 " Index: ", $self->{ INDEX  }, "\n",
+	 "Number: ", $self->{ NUMBER }, "\n",
+	 "   Max: ", $self->{ MAX    }, "\n",
+	 "  Size: ", $self->{ SIZE   }, "\n",
+	 " First: ", $self->{ FIRST  }, "\n",
+	 "  Last: ", $self->{ LAST   }, "\n",
+	 "\n"
      );
 }
 
@@ -239,6 +245,18 @@ sub _dump {
 
 __END__
 
+
+#------------------------------------------------------------------------
+# IMPORTANT NOTE
+#   This documentation is generated automatically from source
+#   templates.  Any changes you make here may be lost.
+# 
+#   The 'docsrc' documentation source bundle is available for download
+#   from http://www.template-toolkit.org/docs.html and contains all
+#   the source templates, XML files, scripts, etc., from which the
+#   documentation for the Template Toolkit is built.
+#------------------------------------------------------------------------
+
 =head1 NAME
 
 Template::Iterator - Data iterator used by the FOREACH directive
@@ -249,8 +267,8 @@ Template::Iterator - Data iterator used by the FOREACH directive
 
 =head1 DESCRIPTION
 
-The C<Template::Iterator> module defines a generic data iterator for use 
-by the C<FOREACH> directive.  
+The Template::Iterator module defines a generic data iterator for use 
+by the FOREACH directive.  
 
 It may be used as the base class for custom iterators.
 
@@ -259,25 +277,25 @@ It may be used as the base class for custom iterators.
 =head2 new($data) 
 
 Constructor method.  A reference to a list of values is passed as the
-first parameter.  Subsequent calls to L<get_first()> and L<get_next()> calls 
+first parameter.  Subsequent calls to get_first() and get_next() calls 
 will return each element from the list.
 
     my $iter = Template::Iterator->new([ 'foo', 'bar', 'baz' ]);
 
 The constructor will also accept a reference to a hash array and will 
 expand it into a list in which each entry is a hash array containing
-a 'C<key>' and 'C<value>' item, sorted according to the hash keys.
+a 'key' and 'value' item, sorted according to the hash keys.
 
     my $iter = Template::Iterator->new({ 
-        foo => 'Foo Item',
-        bar => 'Bar Item',
+	foo => 'Foo Item',
+	bar => 'Bar Item',
     });
 
 This is equivalent to:
 
     my $iter = Template::Iterator->new([
-        { key => 'bar', value => 'Bar Item' },
-        { key => 'foo', value => 'Foo Item' },
+	{ key => 'bar', value => 'Bar Item' },
+	{ key => 'foo', value => 'Foo Item' },
     ]);
 
 When passed a single item which is not an array reference, the constructor
@@ -300,18 +318,18 @@ equivalent to:
 
     my $iter = Template::Iterator->new([ $list ]);
 
-If the object provides an C<as_list()> method then the L<Template::Iterator>
+If the object provides an as_list() method then the Template::Iterator
 constructor will call that method to return the list of data.  For example:
 
     package MyListObject;
-    
+
     sub new {
-        my $class = shift;
-        bless [ @_ ], $class;
+	my $class = shift;
+	bless [ @_ ], $class;
     }
 
     package main;
-    
+
     my $list = MyListObject->new('foo', 'bar');
     my $iter = Template::Iterator->new($list);
 
@@ -319,47 +337,47 @@ This is then functionally equivalent to:
 
     my $iter = Template::Iterator->new([ $list ]);
 
-The iterator will return only one item, a reference to the C<MyListObject>
-object, C<$list>.
+The iterator will return only one item, a reference to the MyListObject
+object, $list.
 
-By adding an C<as_list()> method to the C<MyListObject> class, we can force
-the C<Template::Iterator> constructor to treat the object as a list and 
+By adding an as_list() method to the MyListObject class, we can force
+the Template::Iterator constructor to treat the object as a list and 
 use the data contained within.
 
     package MyListObject;
-    
+
     ...
-    
+
     sub as_list {
-        my $self = shift;
-        return $self;
+	my $self = shift;
+	return $self;
     }
-    
+
     package main;
-    
+
     my $list = MyListObject->new('foo', 'bar');
     my $iter = Template::Iterator->new($list);
 
-The iterator will now return the two items, 'C<foo>' and 'C<bar>', which the 
-C<MyObjectList> encapsulates.
+The iterator will now return the two item, 'foo' and 'bar', which the 
+MyObjectList encapsulates.
 
 =head2 get_first()
 
-Returns a C<($value, $error)> pair for the first item in the iterator set.
-The C<$error> returned may be zero or undefined to indicate a valid datum
-was successfully returned.  Returns an error of C<STATUS_DONE> if the list 
+Returns a ($value, $error) pair for the first item in the iterator set.
+The $error returned may be zero or undefined to indicate a valid datum
+was successfully returned.  Returns an error of STATUS_DONE if the list 
 is empty.
 
 =head2 get_next()
 
-Returns a C<($value, $error)> pair for the next item in the iterator set.
-Returns an error of C<STATUS_DONE> if all items in the list have been 
+Returns a ($value, $error) pair for the next item in the iterator set.
+Returns an error of STATUS_DONE if all items in the list have been 
 visited.
 
 =head2 get_all()
 
-Returns a C<(\@values, $error)> pair for all remaining items in the iterator 
-set.  Returns an error of C<STATUS_DONE> if all items in the list have been 
+Returns a (\@values, $error) pair for all remaining items in the iterator 
+set.  Returns an error of STATUS_DONE if all items in the list have been 
 visited.
 
 =head2 size()
@@ -369,16 +387,17 @@ Returns the size of the data set or undef if unknown.
 =head2 max()
 
 Returns the maximum index number (i.e. the index of the last element) 
-which is equivalent to L<size()> - C<1>.
+which is equivalent to size() - 1.
 
 =head2 index()
 
-Returns the current index number which is in the range C<0> to L<max()>.
+Returns the current index number which is in the range 0 to max().
 
 =head2 count()
 
-Returns the current iteration count in the range C<1> to L<size()>.  This is
-equivalent to L<index()> + C<1>.  
+Returns the current iteration count in the range 1 to size().  This is
+equivalent to index() + 1.  Note that number() is supported as an alias
+for count() for backwards compatability.
 
 =head2 first()
 
@@ -392,35 +411,34 @@ the last iteration of the set.
 
 =head2 prev()
 
-Returns the previous item in the data set, or C<undef> if the iterator is
+Returns the previous item in the data set, or undef if the iterator is
 on the first item.
 
 =head2 next()
 
-Returns the next item in the data set or C<undef> if the iterator is on the 
+Returns the next item in the data set or undef if the iterator is on the 
 last item.
 
 =head1 AUTHOR
 
-Andy Wardley E<lt>abw@wardley.orgE<gt> L<http://wardley.org/>
+Andy Wardley E<lt>abw@kfs.orgE<gt>
+
+L<http://www.andywardley.com/|http://www.andywardley.com/>
+
+=head1 VERSION
+
+Template Toolkit version 2.01, released on 30th March 2001.
 
 =head1 COPYRIGHT
 
-Copyright (C) 1996-2007 Andy Wardley.  All Rights Reserved.
+  Copyright (C) 1996-2001 Andy Wardley.  All Rights Reserved.
+  Copyright (C) 1998-2001 Canon Research Centre Europe Ltd.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
 =head1 SEE ALSO
 
-L<Template>
+L<Template|Template>
 
-=cut
 
-# Local Variables:
-# mode: perl
-# perl-indent-level: 4
-# indent-tabs-mode: nil
-# End:
-#
-# vim: expandtab shiftwidth=4:
