@@ -8,26 +8,33 @@
 #   and instantiated via the USE directive.
 #
 # AUTHOR
-#   Andy Wardley   <abw@wardley.org>
+#   Andy Wardley   <abw@kfs.org>
 #
 # COPYRIGHT
-#   Copyright (C) 1996-2007 Andy Wardley.  All Rights Reserved.
+#   Copyright (C) 1996-2000 Andy Wardley.  All Rights Reserved.
+#   Copyright (C) 1998-2000 Canon Research Centre Europe Ltd.
 #
-#   This module is free software; you can redistribute it an/or
+#   This module is free software; you can redistribute it and/or
 #   modify it under the same terms as Perl itself.
 #
+#----------------------------------------------------------------------------
+#
+# $Id: Plugin.pm,v 2.6 2001/03/30 08:09:23 abw Exp $
+#
 #============================================================================
 
 package Template::Plugin;
 
-use strict;
-use warnings;
-use base 'Template::Base';
+require 5.004;
 
-our $VERSION = 2.70;
-our $DEBUG   = 0 unless defined $DEBUG;
-our $ERROR   = '';
-our $AUTOLOAD;
+use strict;
+use Template::Base;
+
+use vars qw( $VERSION $DEBUG $ERROR $AUTOLOAD );
+use base qw( Template::Base );
+
+$VERSION = sprintf("%d.%02d", q$Revision: 2.6 $ =~ /(\d+)\.(\d+)/);
+$DEBUG   = 0;
 
 
 #========================================================================
@@ -66,38 +73,32 @@ sub load {
 #------------------------------------------------------------------------
 
 sub new {
-    my $class = shift;
-    bless {
-    }, $class;
-}
-
-sub old_new {
     my ($class, $context, $delclass, @params) = @_;
     my ($delegate, $delmod);
 
     return $class->error("no context passed to $class constructor\n")
-        unless defined $context;
+	unless defined $context;
 
     if (ref $delclass) {
-        # $delclass contains a reference to a delegate object
-        $delegate = $delclass;
+	# $delclass contains a reference to a delegate object
+	$delegate = $delclass;
     }
     else {
-        # delclass is the name of a module to load and instantiate
-        ($delmod = $delclass) =~ s|::|/|g;
+	# delclass is the name of a module to load and instantiate
+	($delmod = $delclass) =~ s|::|/|g;
 
-        eval {
-            require "$delmod.pm";
-            $delegate = $delclass->new(@params)
-                || die "failed to instantiate $delclass object\n";
-        };
-        return $class->error($@) if $@;
+	eval {
+	    require "$delmod.pm";
+	    $delegate = $delclass->new(@params)
+		|| die "failed to instantiate $delclass object\n";
+	};
+	return $class->error($@) if $@;
     }
 
     bless {
-        _CONTEXT  => $context, 
-        _DELEGATE => $delegate,
-        _PARAMS   => \@params,
+	_CONTEXT  => $context, 
+	_DELEGATE => $delegate,
+	_PARAMS   => \@params,
     }, $class;
 }
 
@@ -137,8 +138,8 @@ sub OLD_AUTOLOAD {
     return if $method eq 'DESTROY';
 
     if (ref $self eq 'HASH') {
-        my $delegate = $self->{ _DELEGATE } || return;
-        return $delegate->$method(@_);
+	my $delegate = $self->{ _DELEGATE } || return;
+	return $delegate->$method(@_);
     }
     my ($pkg, $file, $line) = caller();
 #    warn "no such '$method' method called on $self at $file line $line\n";
@@ -150,6 +151,18 @@ sub OLD_AUTOLOAD {
 
 __END__
 
+
+#------------------------------------------------------------------------
+# IMPORTANT NOTE
+#   This documentation is generated automatically from source
+#   templates.  Any changes you make here may be lost.
+# 
+#   The 'docsrc' documentation source bundle is available for download
+#   from http://www.template-toolkit.org/docs.html and contains all
+#   the source templates, XML files, scripts, etc., from which the
+#   documentation for the Template Toolkit is built.
+#------------------------------------------------------------------------
+
 =head1 NAME
 
 Template::Plugin - Base class for Template Toolkit plugins
@@ -160,23 +173,23 @@ Template::Plugin - Base class for Template Toolkit plugins
     use base qw( Template::Plugin );
     use Template::Plugin;
     use MyModule;
-    
+
     sub new {
         my $class   = shift;
         my $context = shift;
-        bless {
-            ...
-        }, $class;
+	bless {
+	    ...
+	}, $class;
     }
 
 =head1 DESCRIPTION
 
 A "plugin" for the Template Toolkit is simply a Perl module which 
-exists in a known package location (e.g. C<Template::Plugin::*>) and 
+exists in a known package location (e.g. Template::Plugin::*) and 
 conforms to a regular standard, allowing it to be loaded and used 
 automatically.
 
-The C<Template::Plugin> module defines a base class from which other 
+The Template::Plugin module defines a base class from which other 
 plugin modules can be derived.  A plugin does not have to be derived
 from Template::Plugin but should at least conform to its object-oriented
 interface.
@@ -186,184 +199,193 @@ to avoid conflict with toolkit plugins.  e.g.
 
     package MyOrg::Template::Plugin::FooBar;
 
-Use the L<PLUGIN_BASE|Template::Manual::Config#PLUGIN_BASE> option to specify
-the namespace that you use. e.g.
+Use the PLUGIN_BASE option to specify the namespace that you use.  e.g.
 
     use Template;
     my $template = Template->new({ 
-        PLUGIN_BASE => 'MyOrg::Template::Plugin',
+	PLUGIN_BASE => 'MyOrg::Template::Plugin',
     });
 
-=head1 METHODS
+=head1 PLUGIN API
 
 The following methods form the basic interface between the Template
 Toolkit and plugin modules.
 
-=head2 load($context)
+=over 4
+
+=item load($context)
 
 This method is called by the Template Toolkit when the plugin module
 is first loaded.  It is called as a package method and thus implicitly
 receives the package name as the first parameter.  A reference to the
-L<Template::Context> object loading the plugin is also passed.  The
-default behaviour for the C<load()> method is to simply return the class
-name.  The calling context then uses this class name to call the C<new()>
+Template::Context object loading the plugin is also passed.  The
+default behaviour for the load() method is to simply return the class
+name.  The calling context then uses this class name to call the new()
 package method.
 
     package MyPlugin;
-    
+
     sub load {               # called as MyPlugin->load($context)
-        my ($class, $context) = @_;
-        return $class;       # returns 'MyPlugin'
+	my ($class, $context) = @_;
+	return $class;       # returns 'MyPlugin'
     }
 
-=head2 new($context, @params)
+=item new($context, @params)
 
-This method is called to instantiate a new plugin object for the C<USE>
-directive. It is called as a package method against the class name returned by
-L<load()>. A reference to the L<Template::Context> object creating the plugin
-is passed, along with any additional parameters specified in the C<USE>
-directive.
+This method is called to instantiate a new plugin object for the USE 
+directive.  It is called as a package method against the class name 
+returned by load().  A reference to the Template::Context object creating
+the plugin is passed, along with any additional parameters specified in
+the USE directive.
 
     sub new {                # called as MyPlugin->new($context)
-        my ($class, $context, @params) = @_;
-        bless {
-            _CONTEXT => $context,
-        }, $class;           # returns blessed MyPlugin object
+	my ($class, $context, @params) = @_;
+	bless {
+	    _CONTEXT => $context,
+	}, $class;	     # returns blessed MyPlugin object
     }
 
-=head2 error($error)
+=item error($error)
 
-This method, inherited from the L<Template::Base> module, is used for 
+This method, inherited from the Template::Base module, is used for 
 reporting and returning errors.   It can be called as a package method
-to set/return the C<$ERROR> package variable, or as an object method to 
-set/return the object C<_ERROR> member.  When called with an argument, it
-sets the relevant variable and returns C<undef.>  When called without an
+to set/return the $ERROR package variable, or as an object method to 
+set/return the object _ERROR member.  When called with an argument, it
+sets the relevant variable and returns undef.  When called without an
 argument, it returns the value of the variable.
 
-    package MyPlugin;
-    use base 'Template::Plugin';
-    
     sub new {
-        my ($class, $context, $dsn) = @_;
-        
-        return $class->error('No data source specified')
-            unless $dsn;
-        
-        bless {
-            _DSN => $dsn,
-        }, $class;
+	my ($class, $context, $dsn) = @_;
+
+	return $class->error('No data source specified')
+	    unless $dsn;
+
+	bless {
+	    _DSN => $dsn,
+	}, $class;
     }
 
-    package main;
-    
-    my $something = MyPlugin->new()
-        || die MyPlugin->error(), "\n";
-        
+    ...
+
+    my $something = MyModule->new()
+	|| die MyModule->error(), "\n";
+
     $something->do_something()
-        || die $something->error(), "\n";
+	|| die $something->error(), "\n";
+
+=back
 
 =head1 DEEPER MAGIC
 
-The L<Template::Context> object that handles the loading and use of plugins
-calls the L<new()> and L<error()> methods against the package name returned by
-the L<load()> method. In pseudo-code terms looks something like this:
+The Template::Context object that handles the loading and use of
+plugins calls the new() and error() methods against the package name
+returned by the load() method.  In pseudo-code terms, it might look
+something like this:
 
     $class  = MyPlugin->load($context);       # returns 'MyPlugin'
-    
-    $object = $class->new($context, @params)  # MyPlugin->new(...)
-        || die $class->error();               # MyPlugin->error()
 
-The L<load()> method may alterately return a blessed reference to an
-object instance.  In this case, L<new()> and L<error()> are then called as
+    $object = $class->new($context, @params)  # MyPlugin->new(...)
+	|| die $class->error();               # MyPlugin->error()
+
+The load() method may alterately return a blessed reference to an
+object instance.  In this case, new() and error() are then called as
 I<object> methods against that prototype instance.
 
     package YourPlugin;
-    
+
     sub load {
         my ($class, $context) = @_;
-        bless {
-            _CONTEXT => $context,
-        }, $class;
+	bless {
+	    _CONTEXT => $context,
+	}, $class;
     }
-    
+
     sub new {
-        my ($self, $context, @params) = @_;
-        return $self;
+	my ($self, $context, @params) = @_;
+	return $self;
     }
 
 In this example, we have implemented a 'Singleton' plugin.  One object 
-gets created when L<load()> is called and this simply returns itself for
-each call to L<new().>   
+gets created when load() is called and this simply returns itself for
+each call to new().   
 
 Another implementation might require individual objects to be created
-for every call to L<new(),> but with each object sharing a reference to
+for every call to new(), but with each object sharing a reference to
 some other object to maintain cached data, database handles, etc.
 This pseudo-code example demonstrates the principle.
 
     package MyServer;
-    
+
     sub load {
         my ($class, $context) = @_;
-        bless {
-            _CONTEXT => $context,
-            _CACHE   => { },
-        }, $class;
+	bless {
+	    _CONTEXT => $context,
+	    _CACHE   => { },
+	}, $class;
     }
-    
+
     sub new {
-        my ($self, $context, @params) = @_;
-        MyClient->new($self, @params);
+	my ($self, $context, @params) = @_;
+	MyClient->new($self, @params);
     }
-    
+
     sub add_to_cache   { ... }
-    
+
     sub get_from_cache { ... }
 
+
     package MyClient;
-    
+
     sub new {
-        my ($class, $server, $blah) = @_;
-        bless {
-            _SERVER => $server,
-            _BLAH   => $blah,
-        }, $class;
-    }
-    
-    sub get {
-        my $self = shift;
-        $self->{ _SERVER }->get_from_cache(@_);
-    }
-    
-    sub put {
-        my $self = shift;
-        $self->{ _SERVER }->add_to_cache(@_);
+	my ($class, $server, $blah) = @_;
+	bless {
+	    _SERVER => $server,
+	    _BLAH   => $blah,
+	}, $class;
     }
 
-When the plugin is loaded, a C<MyServer> instance is created. The L<new()>
-method is called against this object which instantiates and returns a C<MyClient>
-object, primed to communicate with the creating C<MyServer>.
+    sub get {
+	my $self = shift;
+	$self->{ _SERVER }->get_from_cache(@_);
+    }
+
+    sub put {
+	my $self = shift;
+	$self->{ _SERVER }->add_to_cache(@_);
+    }
+
+When the plugin is loaded, a MyServer instance is created.  The new() 
+method is called against this object which instantiates and returns a 
+MyClient object, primed to communicate with the creating MyServer.
+
+=head1 Template::Plugin Delegation
+
+As of version 2.01, the Template::Plugin module no longer provides an
+AUTOLOAD method to delegate to other objects or classes.  This was a
+badly designed featured that caused more trouble than good.  You can
+easily add your own AUTOLOAD method to perform delegation if you
+require this kind of functionality.
 
 =head1 AUTHOR
 
-Andy Wardley E<lt>abw@wardley.orgE<gt> L<http://wardley.org/>
+Andy Wardley E<lt>abw@kfs.orgE<gt>
+
+L<http://www.andywardley.com/|http://www.andywardley.com/>
+
+=head1 VERSION
+
+Template Toolkit version 2.01, released on 30th March 2001.
 
 =head1 COPYRIGHT
 
-Copyright (C) 1996-2007 Andy Wardley.  All Rights Reserved.
+  Copyright (C) 1996-2001 Andy Wardley.  All Rights Reserved.
+  Copyright (C) 1998-2001 Canon Research Centre Europe Ltd.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
 =head1 SEE ALSO
 
-L<Template>, L<Template::Plugins>, L<Template::Context>
+L<Template|Template>, L<Template::Plugins|Template::Plugins>, L<Template::Context|Template::Context>
 
-=cut
 
-# Local Variables:
-# mode: perl
-# perl-indent-level: 4
-# indent-tabs-mode: nil
-# End:
-#
-# vim: expandtab shiftwidth=4:
